==> zio-aws-mediatailor_3-5.17.124.3-sources.jar: zio/aws/mediatailor/model/AvailSuppression.scala <==
package zio.aws.mediatailor.model
import zio.aws.mediatailor.model.primitives.__string
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import scala.jdk.CollectionConverters.*
final case class AvailSuppression(
    mode: Option[zio.aws.mediatailor.model.Mode] = None,
    value: Option[__string] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.mediatailor.model.AvailSuppression = {
    import AvailSuppression.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.mediatailor.model.AvailSuppression
      .builder()
      .optionallyWith(mode.map(value => value.unwrap))(_.mode)
      .optionallyWith(
        value.map(value => __string.unwrap(value): java.lang.String)
      )(_.value)
      .build()
  }
  def asReadOnly: zio.aws.mediatailor.model.AvailSuppression.ReadOnly =
    zio.aws.mediatailor.model.AvailSuppression.wrap(buildAwsValue())
}
object AvailSuppression {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.mediatailor.model.AvailSuppression
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.mediatailor.model.AvailSuppression =
      zio.aws.mediatailor.model
        .AvailSuppression(mode.map(value => value), value.map(value => value))
    def mode: Option[zio.aws.mediatailor.model.Mode]
    def value: Option[__string]
    def getMode: ZIO[Any, AwsError, zio.aws.mediatailor.model.Mode] =
      AwsError.unwrapOptionField("mode", mode)
    def getValue: ZIO[Any, AwsError, __string] =
      AwsError.unwrapOptionField("value", value)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.mediatailor.model.AvailSuppression
  ) extends zio.aws.mediatailor.model.AvailSuppression.ReadOnly {
    override val mode: Option[zio.aws.mediatailor.model.Mode] = scala
      .Option(impl.mode())
      .map(value => zio.aws.mediatailor.model.Mode.wrap(value))
    override val value: Option[__string] = scala
      .Option(impl.value())
      .map(value => zio.aws.mediatailor.model.primitives.__string(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.mediatailor.model.AvailSuppression
  ): zio.aws.mediatailor.model.AvailSuppression.ReadOnly = new Wrapper(impl)
}

==> zio-aws-mediatailor_3-5.17.158.3-sources.jar: zio/aws/mediatailor/model/AvailSuppression.scala <==
package zio.aws.mediatailor.model
import zio.aws.mediatailor.model.primitives.__string
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import scala.jdk.CollectionConverters.*
final case class AvailSuppression(
    mode: Option[zio.aws.mediatailor.model.Mode] = None,
    value: Option[__string] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.mediatailor.model.AvailSuppression = {
    import AvailSuppression.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.mediatailor.model.AvailSuppression
      .builder()
      .optionallyWith(mode.map(value => value.unwrap))(_.mode)
      .optionallyWith(value.map(value => value: java.lang.String))(_.value)
      .build()
  }
  def asReadOnly: zio.aws.mediatailor.model.AvailSuppression.ReadOnly =
    zio.aws.mediatailor.model.AvailSuppression.wrap(buildAwsValue())
}
object AvailSuppression {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.mediatailor.model.AvailSuppression
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.mediatailor.model.AvailSuppression =
      zio.aws.mediatailor.model
        .AvailSuppression(mode.map(value => value), value.map(value => value))
    def mode: Option[zio.aws.mediatailor.model.Mode]
    def value: Option[__string]
    def getMode: ZIO[Any, AwsError, zio.aws.mediatailor.model.Mode] =
      AwsError.unwrapOptionField("mode", mode)
    def getValue: ZIO[Any, AwsError, __string] =
      AwsError.unwrapOptionField("value", value)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.mediatailor.model.AvailSuppression
  ) extends zio.aws.mediatailor.model.AvailSuppression.ReadOnly {
    override val mode: Option[zio.aws.mediatailor.model.Mode] = scala
      .Option(impl.mode())
      .map(value => zio.aws.mediatailor.model.Mode.wrap(value))
    override val value: Option[__string] =
      scala.Option(impl.value()).map(value => value: __string)
  }
  def wrap(
      impl: software.amazon.awssdk.services.mediatailor.model.AvailSuppression
  ): zio.aws.mediatailor.model.AvailSuppression.ReadOnly = new Wrapper(impl)
}
